l18n contributors list
======================


Code
----

Thomas Khyn, thomas@ksytek.com


Languages
---------

en: Thomas Khyn, thomas[at]ksytek.com
fr: Thomas Khyn, thomas[at]ksytek.com
de: Philipp Steinhardt, steinhardt[at]myvision.de
cs: Jan Čermák, sairon[at]sairon.cz
zh: Charlotte Blanc, charblanc17[at]gmail.com
